@@ -30,25 +30,35 @@ from metafab_python.model.create_collection_request import CreateCollectionReque
 from metafab_python.model.create_contract_request import CreateContractRequest
 from metafab_python.model.create_currency200_response import CreateCurrency200Response
 from metafab_python.model.create_currency_request import CreateCurrencyRequest
+from metafab_python.model.create_exchange200_response import CreateExchange200Response
+from metafab_python.model.create_exchange_request import CreateExchangeRequest
 from metafab_python.model.create_game_request import CreateGameRequest
 from metafab_python.model.create_player_request import CreatePlayerRequest
 from metafab_python.model.currency_model import CurrencyModel
+from metafab_python.model.exchange_model import ExchangeModel
+from metafab_python.model.exchange_offer import ExchangeOffer
 from metafab_python.model.game_model import GameModel
 from metafab_python.model.get_collections200_response_inner import GetCollections200ResponseInner
 from metafab_python.model.get_collections200_response_inner_all_of import GetCollections200ResponseInnerAllOf
 from metafab_python.model.get_currencies200_response_inner import GetCurrencies200ResponseInner
 from metafab_python.model.get_currencies200_response_inner_all_of import GetCurrencies200ResponseInnerAllOf
 from metafab_python.model.get_currency_fees200_response import GetCurrencyFees200Response
+from metafab_python.model.get_exchanges200_response_inner import GetExchanges200ResponseInner
+from metafab_python.model.grant_collection_role_request import GrantCollectionRoleRequest
+from metafab_python.model.grant_currency_role_request import GrantCurrencyRoleRequest
 from metafab_python.model.mint_collection_item_request import MintCollectionItemRequest
 from metafab_python.model.mint_currency_request import MintCurrencyRequest
 from metafab_python.model.player_model import PlayerModel
+from metafab_python.model.revoke_collection_role_request import RevokeCollectionRoleRequest
 from metafab_python.model.set_collection_approval_request import SetCollectionApprovalRequest
 from metafab_python.model.set_collection_item_timelock_request import SetCollectionItemTimelockRequest
 from metafab_python.model.set_currency_fees_request import SetCurrencyFeesRequest
+from metafab_python.model.set_exchange_offer_request import SetExchangeOfferRequest
 from metafab_python.model.transaction_model import TransactionModel
 from metafab_python.model.transfer_collection_item_request import TransferCollectionItemRequest
 from metafab_python.model.transfer_currency_request import TransferCurrencyRequest
 from metafab_python.model.update_game_request import UpdateGameRequest
 from metafab_python.model.update_player_request import UpdatePlayerRequest
 from metafab_python.model.wallet_model import WalletModel
+from metafab_python.model.withdraw_from_exchange_request import WithdrawFromExchangeRequest
 from metafab_python.model.write_contract_request import WriteContractRequest
